from mastercardapicore import *

# import apis resourceconfig
from mastercardstpapisdk.resourceconfig import ResourceConfig


# import apis into api package
from mastercardstpapisdk.payment import *
from mastercardstpapisdk.payments import *
from mastercardstpapisdk.provider import *
from mastercardstpapisdk.providers import *
from mastercardstpapisdk.supplier import *
from mastercardstpapisdk.suppliers import *
